@@ -15,10 +15,11 @@ Common utility functions used in scripts.
 
 import os
 import re
+import sys
 import socket
 import logging
 from datetime import datetime
-from LbNightlyTools.Utils import TaskQueue, recursive_update
+from LbNightlyTools.Utils import TaskQueue, recursive_update, SlotAborted
 from LbNightlyTools.Utils import retry_call as call, TemporaryDir
 from LbNightlyTools.Configuration import findSlot, Slot
 
@@ -53,6 +54,13 @@ class PlainScript(_PlainScript):
             for h in self.log.handlers:
                 h.setFormatter(formatter)
 
+    def run(self, args=sys.argv[1:]):
+        try:
+            return _PlainScript.run(self, args)
+        except SlotAborted as err:
+            self.log.warning("slot was aborted: %s", err)
+            return 0
+
 
 def addBasicOptions(parser):
     '''
@@ -680,9 +688,19 @@ class BaseScript(PlainScript):
             self.receivers.append(
                 RsyncDestination(self.options.rsync_dest, self))
         if hasattr(self.options, 'submit'):
-            self.receivers.append(DashboardUpdate(self))
+            db_update = DashboardUpdate(self)
+            if db_update.dashboard:
+
+                def abort_check():
+                    db_update.dashboard.assert_not_aborted(db_update.doc_name)
+
+                self.assert_not_aborted = abort_check
+            self.receivers.append(db_update)
             self.receivers.append(PeriodicTestMsg(self))
 
+    def assert_not_aborted(self):
+        pass
+
     def _setup(self,
                build_dir=None,
                json_type=None,
@@ -708,7 +726,8 @@ class BaseScript(PlainScript):
             self.args[0],
             flavour=opts.flavour,
             server=opts.db_url,
-            dbname=opts.db_name)
+            dbname=opts.db_name,
+            raise_if_aborted=True)
 
         from LbNightlyTools.Utils import setDayNamesEnv
         setDayNamesEnv()
@@ -746,7 +765,7 @@ class BaseScript(PlainScript):
             try:
                 opts.projects = set(proj_names[p.strip().lower()]
                                     for p in opts.projects.split(','))
-            except KeyError, exc:
+            except KeyError as exc:
                 self.parser.error(
                     'requested project not in slot: "%s"' % exc.args)
         else:
