@@ -106,11 +106,7 @@ class RpmDirConfig:
 class LHCbBaseRpmSpec(object):
     """ Class representing a LHCb project"""
 
-    def __init__(self,
-                 project,
-                 version,
-                 prodRPMReleaseDir="/eos/project/l/lhcbwebsites/"
-                 "www/lhcb-rpm/lhcb"):
+    def __init__(self, project, version, prodRPMReleaseDir=None):
         self._project = project
         self._version = version
         self._lhcb_release_version = 0
